<?php
// LINUX SERVER CONFIG WIZARD
//
// Copyright (c) 2010 Nagios Enterprises, LLC.  All rights reserved.
//  
// $Id: linux-server.inc.php 285 2010-08-17 20:03:50Z egalstad $

include_once(dirname(__FILE__).'/../configwizardhelper.inc.php');

// run the initialization function
linux_server_configwizard_init();

function linux_server_configwizard_init(){
	
	$name="linux-server";
	
	$args=array(
		CONFIGWIZARD_NAME => $name,
		CONFIGWIZARD_TYPE => CONFIGWIZARD_TYPE_MONITORING,
		CONFIGWIZARD_DESCRIPTION => "Monitor a remote Linux server.",
		CONFIGWIZARD_DISPLAYTITLE => "Linux Server",
		CONFIGWIZARD_FUNCTION => "linux_server_configwizard_func",
		CONFIGWIZARD_PREVIEWIMAGE => "linux-server.png",
		);

	register_configwizard($name,$args);
	}
	

function linux_server_configwizard_func($mode="",$inargs=null,&$outargs,&$result){

	$wizard_name="linux-server";
	
	$agent_url="http://assets.nagios.com/downloads/nagiosxi/agents/linux-nrpe-agent.tar.gz";
	$agent_doc_url="http://assets.nagios.com/downloads/nagiosxi/Installing_The_XI_Linux_Agent.pdf";

	// initialize return code and output
	$result=0;
	$output="";
	
	// initialize output args - pass back the same data we got
	$outargs[CONFIGWIZARD_PASSBACK_DATA]=$inargs;


	switch($mode){
		case CONFIGWIZARD_MODE_GETSTAGE1HTML:
		
			$address=grab_array_var($inargs,"address","");
			
			$output='

	<div class="sectionTitle">Linux Server Information</div>
	
			
	<table>
	
	<tr>
	<td valign="top">
	<label>IP Address:</label><br class="nobr" />
	</td>
	<td>
<input type="text" size="40" name="address" id="address" value="'.$address.'" class="textfield" /><br class="nobr" />
	The IP address or FQDNS name of the Linux server you\'d like to monitor.<br><br>
	</td>
	</tr>

	<tr>
	<td valign="top">
	<label>Linux Distribution:</label><br class="nobr" />
	</td>
	<td>
	<select name="linuxdistro" id="linuxdistro">
	<option value="RHEL">RedHat Enterprise Linux</option>
	<option value="CentOS">CentOS</option>
	<option value="Fedora">Fedora Core</option>
	<option value="Ubuntu">Ubuntu</option>
	<option value="Debian">Debian</option>
	<option value="Other" SELECTED>Other</option>

	</select>
	<br class="nobr" />
	The Linux distribution running on the server you\'d like to monitor.
	</td>
	</tr>

	</table>
			';
			break;
			
		case CONFIGWIZARD_MODE_VALIDATESTAGE1DATA:
		
			// get variables that were passed to us
			$address=grab_array_var($inargs,"address","");
			$linuxdistro=grab_array_var($inargs,"linuxdistro","");
			
			
			// check for errors
			$errors=0;
			$errmsg=array();
			//$errmsg[$errors++]="Address: '$address'";
			if(have_value($address)==false)
				$errmsg[$errors++]="No address specified.";
			//else if(!valid_ip($address))
				//$errmsg[$errors++]="Invalid IP address.";
				
			if($errors>0){
				$outargs[CONFIGWIZARD_ERROR_MESSAGES]=$errmsg;
				$result=1;
				}
				
			break;
			
		case CONFIGWIZARD_MODE_GETSTAGE2HTML:
		
			// get variables that were passed to us
			$address=grab_array_var($inargs,"address");
			$linuxdistro=grab_array_var($inargs,"linuxdistro","");

			$ha=@gethostbyaddr($address);
			if($ha=="")
				$ha=$address;
			$hostname=grab_array_var($inargs,"hostname",$ha);
			
			//$ipaddress=@gethostbyname($address);
			
			$password="";
			
			$load_warning="15,10,5";
			$load_critical="30,20,10";
			$cpustats_warning="85";
			$cpustats_critical="95";
			$memory_warning="85";
			$memory_critical="95";
			$disk_warning="80";
			$disk_critical="90";
			$openfiles_warning="30";
			$openfiles_critical="50";
			$swap_warning="50";
			$swap_critical="80";
			$users_warning="5";
			$users_critical="10";
			$procs_warning="150";
			$procs_critical="250";
			
			
		
			$output='
			
			
		<input type="hidden" name="address" value="'.$address.'">
		<input type="hidden" name="linuxdistro" value="'.$linuxdistro.'">

		
	<div class="sectionTitle">Linux Server Details</div>
	
	<table>

	<tr>
	<td valign="top">
	<label>IP Address:</label><br class="nobr" />
	</td>
	<td>
<input type="text" size="40" name="address" id="address" value="'.$address.'" class="textfield" disabled/><br class="nobr" />
	</td>
	</tr>
	';

	$icon=nagioscore_get_ui_url()."images/logos/".linux_server_configwizard_get_distro_icon($linuxdistro);
	
	$output.='
	<tr>
	<td valign="top">
	<label>Server Distro:</label><br class="nobr" />
	</td>
	<td><img src="'.$icon.'" style=""><br>'.$linuxdistro.'<br class="nobr" />
	</td>
	</tr>

	<tr>
	<td valign="top">
	<label>Host Name:</label><br class="nobr" />
	</td>
	<td>
<input type="text" size="20" name="hostname" id="hostname" value="'.$hostname.'" class="textfield" /><br class="nobr" />
	The name you\'d like to have associated with this Linux server.
	</td>
	</tr>

	</table>

	<div class="sectionTitle">Linux Agent</div>
	
	<p>You\'ll need to install an agent on the Linux server in order to monitor its metrics.</p>

	<table>

	<tr>
	<td>
	<label>Agent Download:</label><br class="nobr" />
	</td>
	<td>
	<a href="'.$agent_url.'"><img src="'.theme_image("download.png").'"></a> <a href="'.$agent_url.'"><b>Download Agent<b></a>
	</td>
	</tr>
	
	<tr>
	<td>
	<label>Agent Install Instructions:</label><br class="nobr" />
	</td>
	<td>
	<a href="'.$agent_doc_url.'"><img src="'.theme_image("download.png").'"></a> <a href="'.$agent_doc_url.'"><b>Download Agent Installation Instructions<b></a>
	</td>
	</tr>
	
	</table>

	<div class="sectionTitle">Server Metrics</div>
	
	<p>Specify which services you\'d like to monitor for the Linux server.</p>
	
	<table>

	<tr>
	<td valign="top">
	<input type="checkbox" class="checkbox" name="services[ping]" checked>
	</td>
	<td>
	<b>Ping</b><br>
	Monitors the server with an ICMP "ping".  Useful for watching network latency and general uptime.<br><br>
	</td>
	</tr>
	';

	$RHEL=($linuxdistro=="RHEL" || $linuxdistro=="Fedora" || $linuxdistro=="CentOS");
	if($RHEL){
		$output.='
		<tr>
		<td valign="top">
		<input type="checkbox" class="checkbox" name="services[yum]" checked>
		</td>
		<td>
		<b>Yum Update Status</b><br>
		Monitors the server to ensure it\'s up to date with the latest RPM packages.<br><br>
		</td>
		</tr>
		';
		}

	$DEB=($linuxdistro=="Debian" || $linuxdistro=="Ubuntu");
	if($DEB){
		$output.='
		<tr>
		<td valign="top">
		<input type="checkbox" class="checkbox" name="services[apt]" checked>
		</td>
		<td>

		<b>APT Update Status</b><br>
		Monitors the server to ensure it\'s up to date with the latest DEB packages.<br><br>
		</td>
		</tr>
		';
		}
		
	$output.='
	<tr>
	<td valign="top">
	<input type="checkbox" class="checkbox" name="services[load]" checked>
	</td>
	<td>
	<b>Load</b><br>
	Monitors the load on the server (1/5/15 minute values).<br>
	<label>Warning Load:</label> <input type="text" size="7" name="serviceargs[load_warning]" value="'.$load_warning.'" class="textfield" />
	<label>Critical Load:</label> <input type="text" size="7" name="serviceargs[load_critical]" value="'.$load_critical.'" class="textfield" /><br><br>
	</td>
	</tr>

	<tr>
	<td valign="top">';
	if($DEB) $output.='<input type="checkbox" class="checkbox" name="services[cpustats]">';
	else $output.='<input type="checkbox" class="checkbox" name="services[cpustats]" checked>';
	$output.='
	</td>
	<td>
	<b>CPU Statistics</b><br>';
	if($DEB) $output.='Monitors the server CPU statistics (% user, system, iowait, and idle).  (The sysstat package must be installed.)<br>';
	else $output.='Monitors the server CPU statistics (% user, system, iowait, and idle).<br>';
	$output.='
	<label>I/O Wait Warning Level:</label> <input type="text" size="2" name="serviceargs[cpustats_warning]" value="'.$cpustats_warning.'" class="textfield" />%
	<label>I/O Wait Critical Load:</label> <input type="text" size="2" name="serviceargs[cpustats_critical]" value="'.$cpustats_critical.'" class="textfield" />%<br><br>
	</td>
	</tr>

	<tr>
	<td valign="top">
	<input type="checkbox" class="checkbox" name="services[memory]" checked>
	</td>
	<td>
	<b>Memory Usage</b><br>
	Monitors the memory usage on the server.<br>
	<label>Warning Usage:</label> <input type="text" size="2" name="serviceargs[memory_warning]" value="'.$memory_warning.'" class="textfield" />%
	<label>Critical Usage:</label> <input type="text" size="2" name="serviceargs[memory_critical]" value="'.$memory_critical.'" class="textfield" />%<br><br>
	</td>
	</tr>

	<tr>
	<td valign="top">
	<input type="checkbox" class="checkbox" name="services[swap]" checked>
	</td>
	<td>
	<b>Swap Usage</b><br>
	Monitors the swap usage on the server.<br>
	<label>Warning Usage:</label> <input type="text" size="2" name="serviceargs[swap_warning]" value="'.$swap_warning.'" class="textfield" />%
	<label>Critical Usage:</label> <input type="text" size="2" name="serviceargs[swap_critical]" value="'.$swap_critical.'" class="textfield" />%<br><br>
	</td>
	</tr>

	<tr>
	<td valign="top">
	<input type="checkbox" class="checkbox" name="services[openfiles]" checked>
	</td>
	<td>
	<b>Open Files</b><br>
	Monitors the number of open files on the server.<br>
	<label>Warning Usage:</label> <input type="text" size="2" name="serviceargs[openfiles_warning]" value="'.$openfiles_warning.'" class="textfield" />%
	<label>Critical Usage:</label> <input type="text" size="2" name="serviceargs[openfiles_critical]" value="'.$openfiles_critical.'" class="textfield" />%<br><br>
	</td>
	</tr>

	<tr>
	<td valign="top">
	<input type="checkbox" class="checkbox" name="services[users]" checked>
	</td>
	<td>
	<b>Users</b><br>
	Monitors the number of users currently logged in to the server.<br>
	<label>Warning Number:</label> <input type="text" size="2" name="serviceargs[users_warning]" value="'.$users_warning.'" class="textfield" />
	<label>Critical Number:</label> <input type="text" size="2" name="serviceargs[users_critical]" value="'.$users_critical.'" class="textfield" /><br><br>
	</td>
	</tr>

	<tr>
	<td valign="top">
	<input type="checkbox" class="checkbox" name="services[procs]" checked>
	</td>
	<td>
	<b>Total Processes</b><br>
	Monitors the total number of processes running on the server.<br>
	<label>Warning Number:</label> <input type="text" size="2" name="serviceargs[procs_warning]" value="'.$procs_warning.'" class="textfield" />
	<label>Critical Number:</label> <input type="text" size="2" name="serviceargs[procs_critical]" value="'.$procs_critical.'" class="textfield" /><br><br>
	</td>
	</tr>

	<tr>
	<td valign="top">
	<input type="checkbox" class="checkbox" name="services[disk]" checked>
	</td>
	<td>
	<b>Disk Usage</b><br>
	Monitors disk usage on the server.  Paths can be mount points or partition names.<br>
	<table>
	';
	for($x=0;$x<3;$x++){
		$checkedstr="";
		if($x==0)
			$checkedstr="checked";
		$output.='<tr>';
		//$output.='<td><input type="checkbox" class="checkbox" name="services[disk]['.$x.']" '.$checkedstr.'></td>';
		$disk_name="";
		if($x==0)
			$disk_name="/";
		$output.='<td><label>Path:</label>  <input type="text" size="10" name="serviceargs[disk]['.$x.']" value="'.$disk_name.'" class="textfield" />';
		$disk_warning=20;
		$disk_critical=10;
		$output.='<td><label>Warning Usage:</label> <input type="text" size="2" name="serviceargs[disk_warning]['.$x.']" value="'.$disk_warning.'" class="textfield" />% Free
	<label>Critical Usage:</label> <input type="text" size="2" name="serviceargs[disk_critical]['.$x.']" value="'.$disk_critical.'" class="textfield" />% Free</td>';
		$output.='</tr>';
		}
	if($RHEL || $DEB){
	$output.='
	</table>
	</td>
	</tr>

	</table>

	<div class="sectionTitle">Services</div>
	
	<p>Specify any services normally started by the init process that should be monitored to ensure they\'re in a running state.</p>
	
	<table>
	
	<tr><th></th><th>init.d Service</th><th>Display Name</th></tr>
	';
	for($x=0;$x<7;$x++){
		$servicestring="";
		$servicename="";
		$checked="";
		if($x==0){
			if($DEB) $servicestring="ssh";
			else $servicestring="sshd";
			$servicename="SSH Server";
			}
		if($x==1){
			if($DEB) $servicestring="cron";
			else $servicestring="crond";
			$servicename="Cron Scheduling Daemon";
			}
		if($x==2){
			if($DEB) $servicestring="rsyslog";
			else $servicestring="syslog";
			$servicename="System Logging Daemon";
			}
		if($x==3){
			if($DEB) $servicestring="apache2";	
			else $servicestring="httpd";
			$servicename="Apache Web Server";
			}
		if($x==4){
			if($DEB) $servicestring="mysql";
			else $servicestring="mysqld";
			$servicename="MySQL Server";
			}
		if($x==5){
			if($linuxdistro=="Ubuntu"){
				$servicestring="postfix";
				$servicename="Postfix Mail Transfer Agent";
			}elseif($linuxdistro=="Debian"){
				$servicestring="exim4";
				$servicename="Exim4 Mail Transfer Agent";
			}else{
				$servicestring="sendmail";
				$servicename="Sendmail Mail Transfer Agent";
				}
			}
		if($x==6){
			$servicestring="dovecot";
			$servicename="Dovecot Mail Server";
			}
		if($x<=3)
			$checked="CHECKED";
		$output.='<tr><td><input type="checkbox" class="checkbox" name="services[servicestate]['.$x.']" '.$checked.'></td><td><input type="text" size="15" name="serviceargs[servicestate]['.$x.'][service]" value="'.$servicestring.'" class="textfield" /></td><td><input type="text" size="20" name="serviceargs[servicestate]['.$x.'][name]" value="'.$servicename.'" class="textfield" /></td></tr>';
	}	}
	$output.='
	</table>

	<div class="sectionTitle">Processes</div>
	
	<p>Specify any process names that should be monitored to ensure they\'re running.</p>
	
	<table>
	
	<tr><th></th><th>Linux Process</th><th>Display Name</th></tr>
	';
	for($x=0;$x<7;$x++){
		$processstring="";
		$processname="";
		if($x==0){
			$processstring="sendmail";
			$processname="Sendmail";
			}
		$output.='<tr><td><input type="checkbox" class="checkbox" name="services[processstate]['.$x.']" ></td><td><input type="text" size="15" name="serviceargs[processstate]['.$x.'][process]" value="'.$processstring.'" class="textfield" /></td><td><input type="text" size="20" name="serviceargs[processstate]['.$x.'][name]" value="'.$processname.'" class="textfield" /></td></tr>';
		}
	$output.='
	</table>

			';
			break;
			
		case CONFIGWIZARD_MODE_VALIDATESTAGE2DATA:
		
			// get variables that were passed to us
			$address=grab_array_var($inargs,"address");
			$hostname=grab_array_var($inargs,"hostname");
			$linuxdistro=grab_array_var($inargs,"linuxdistro","");
			
			// check for errors
			$errors=0;
			$errmsg=array();
			if(is_valid_host_name($hostname)==false)
				$errmsg[$errors++]="Invalid host name.";
				
			if($errors>0){
				$outargs[CONFIGWIZARD_ERROR_MESSAGES]=$errmsg;
				$result=1;
				}
				
			break;

			
		case CONFIGWIZARD_MODE_GETSTAGE3HTML:
		
			// get variables that were passed to us
			$address=grab_array_var($inargs,"address");
			$hostname=grab_array_var($inargs,"hostname");
			$linuxdistro=grab_array_var($inargs,"linuxdistro","");
			$services=grab_array_var($inargs,"services");
			$serviceargs=grab_array_var($inargs,"serviceargs");
		
			$output='
			
		<input type="hidden" name="address" value="'.$address.'">
		<input type="hidden" name="hostname" value="'.$hostname.'">
		<input type="hidden" name="linuxdistro" value="'.$linuxdistro.'">
		<input type="hidden" name="services_serial" value="'.base64_encode(serialize($services)).'">
		<input type="hidden" name="serviceargs_serial" value="'.base64_encode(serialize($serviceargs)).'">
		
		<!--SERVICES='.serialize($services).'<BR>
		SERVICEARGS='.serialize($serviceargs).'<BR>-->
		
			';
			break;
			
		case CONFIGWIZARD_MODE_VALIDATESTAGE3DATA:
				
			break;
			
		case CONFIGWIZARD_MODE_GETFINALSTAGEHTML:
			
			
			$output='
			<!--
			<p>Dont forget to download and install the Linux Agent on the target server!</p>
			<p><a href="'.$agent_url.'"><img src="'.theme_image("download.png").'"></a> <a href="'.$agent_url.'"><b>Download Agent<b></a></p>
			//-->
			';
			break;
			
		case CONFIGWIZARD_MODE_GETOBJECTS:
		
			$hostname=grab_array_var($inargs,"hostname","");
			$address=grab_array_var($inargs,"address","");
			$linuxdistro=grab_array_var($inargs,"linuxdistro","");
			$hostaddress=$address;
			
			$services_serial=grab_array_var($inargs,"services_serial","");
			$serviceargs_serial=grab_array_var($inargs,"serviceargs_serial","");
			
			$services=unserialize(base64_decode($services_serial));
			$serviceargs=unserialize(base64_decode($serviceargs_serial));
			
			/*
			echo "SERVICES<BR>";
			print_r($services);
			echo "<BR>";
			echo "SERVICEARGS<BR>";
			print_r($serviceargs);
			echo "<BR>";
			*/
			
			// save data for later use in re-entrance
			$meta_arr=array();
			$meta_arr["hostname"]=$hostname;
			$meta_arr["address"]=$address;
			$meta_arr["linuxdistro"]=$linuxdistro;
			$meta_arr["services"]=$services;
			$meta_arr["serivceargs"]=$serviceargs;
			save_configwizard_object_meta($wizard_name,$hostname,"",$meta_arr);			
			
			$objs=array();
			
			$icon=linux_server_configwizard_get_distro_icon($linuxdistro);
			
			if(!host_exists($hostname)){
				$objs[]=array(
					"type" => OBJECTTYPE_HOST,
					"use" => "xiwizard_linuxserver_host",
					"host_name" => $hostname,
					"address" => $hostaddress,
					"icon_image" => $icon,
					"statusmap_image" => $icon,
					"_xiwizard" => $wizard_name,
					);
				}

			$RHEL=($linuxdistro=="RHEL" || $linuxdistro=="Fedora" || $linuxdistro=="CentOS");
			$DEB=($linuxdistro=="Debian" || $linuxdistro=="Ubuntu");
			// see which services we should monitor
			foreach($services as $svc => $svcstate){
			
				//echo "PROCESSING: $svc -> $svcstate<BR>\n";
		
				switch($svc){
				
					case "ping":
						$objs[]=array(
							"type" => OBJECTTYPE_SERVICE,
							"host_name" => $hostname,
							"service_description" => "Ping",
							"use" => "xiwizard_linuxserver_ping_service",
							"_xiwizard" => $wizard_name,
							);
						break;
					
					case "yum":
						if(!$RHEL) break;
						$objs[]=array(
							"type" => OBJECTTYPE_SERVICE,
							"host_name" => $hostname,
							"service_description" => "Yum Updates",
							"use" => "xiwizard_nrpe_service",
							"check_command" => "check_nrpe!check_yum!",
							"_xiwizard" => $wizard_name,
							);
						break;
					
					case "apt":
						if(!$DEB) break;
						$objs[]=array(
							"type" => OBJECTTYPE_SERVICE,
							"host_name" => $hostname,
							"service_description" => "APT Updates",
							"use" => "xiwizard_nrpe_service",
							"check_command" => "check_nrpe!check_apt!-a '-U'",
							"_xiwizard" => $wizard_name,
							);
						break;
					
					case "load":
						$objs[]=array(
							"type" => OBJECTTYPE_SERVICE,
							"host_name" => $hostname,
							"service_description" => "Load",
							"use" => "xiwizard_nrpe_service",
							"check_command" => "check_nrpe!check_load!-a '-w ".$serviceargs["load_warning"]." -c ".$serviceargs["load_critical"]."'",
							"_xiwizard" => $wizard_name,
							);
						break;
					
					case "cpustats":
						$objs[]=array(
							"type" => OBJECTTYPE_SERVICE,
							"host_name" => $hostname,
							"service_description" => "CPU Stats",
							"use" => "xiwizard_nrpe_service",
							"check_command" => "check_nrpe!check_cpu_stats!-a '-w ".$serviceargs["cpustats_warning"]." -c ".$serviceargs["cpustats_critical"]."'",
							"_xiwizard" => $wizard_name,
							);
						break;
					
					case "memory":
						$objs[]=array(
							"type" => OBJECTTYPE_SERVICE,
							"host_name" => $hostname,
							"service_description" => "Memory Usage",
							"use" => "xiwizard_nrpe_service",
							"check_command" => "check_nrpe!check_mem!-a '-w ".(100-intval($serviceargs["cpustats_warning"]))." -c ".(100-intval($serviceargs["cpustats_critical"]))."'",
							"_xiwizard" => $wizard_name,
							);
						break;
					
					case "swap":
						$objs[]=array(
							"type" => OBJECTTYPE_SERVICE,
							"host_name" => $hostname,
							"service_description" => "Swap Usage",
							"use" => "xiwizard_nrpe_service",
							"check_command" => "check_nrpe!check_swap!-a '-w ".(100-intval($serviceargs["swap_warning"]))." -c ".(100-intval($serviceargs["swap_critical"]))."'",
							"_xiwizard" => $wizard_name,
							);
						break;
					
					case "openfiles":
						$objs[]=array(
							"type" => OBJECTTYPE_SERVICE,
							"host_name" => $hostname,
							"service_description" => "Open Files",
							"use" => "xiwizard_nrpe_service",
							"check_command" => "check_nrpe!check_open_files!-a '-w ".$serviceargs["openfiles_warning"]." -c ".$serviceargs["openfiles_critical"]."'",
							"_xiwizard" => $wizard_name,
							);
						break;
					
					case "users":
						$objs[]=array(
							"type" => OBJECTTYPE_SERVICE,
							"host_name" => $hostname,
							"service_description" => "Users",
							"use" => "xiwizard_nrpe_service",
							"check_command" => "check_nrpe!check_users!-a '-w ".$serviceargs["users_warning"]." -c ".$serviceargs["users_critical"]."'",
							"_xiwizard" => $wizard_name,
							);
						break;
					
					case "procs":
						$objs[]=array(
							"type" => OBJECTTYPE_SERVICE,
							"host_name" => $hostname,
							"service_description" => "Total Processes",
							"use" => "xiwizard_nrpe_service",
							"check_command" => "check_nrpe!check_procs!-a '-w ".$serviceargs["procs_warning"]." -c ".$serviceargs["procs_critical"]."'",
							"_xiwizard" => $wizard_name,
							);
						break;
					
					case "disk":
						$donedisks=array();
						$diskid=0;
						foreach($serviceargs["disk"] as $diskname){
						
							if($diskname=="")
								continue;
						
							//echo "HANDLING DISK: $diskname<BR>";
							
							// we already configured this disk
							if(in_array($diskname,$donedisks))
								continue;
							$donedisks[]=$diskname;
							
							$objs[]=array(
								"type" => OBJECTTYPE_SERVICE,
								"host_name" => $hostname,
								"service_description" => $diskname." Disk Usage",
								"use" => "xiwizard_nrpe_service",
								"check_command" => "check_nrpe!check_disk!-a '-w ".$serviceargs["disk_warning"][$diskid]."% -c ".$serviceargs["disk_critical"][$diskid]."% -p ".$diskname."'",
								"_xiwizard" => $wizard_name,
								);		

							$diskid++;
							}
						break;
					
					case "servicestate":
						if(!($RHEL || $DEB)) break;

						$enabledservices=$svcstate;			
						foreach($enabledservices as $sid => $sstate){
						
							$sname=$serviceargs["servicestate"][$sid]["service"];
							$sdesc=$serviceargs["servicestate"][$sid]["name"];
						
							$objs[]=array(
								"type" => OBJECTTYPE_SERVICE,
								"host_name" => $hostname,
								"service_description" => $sdesc,
								"use" => "xiwizard_nrpe_service",
								"check_command" => "check_nrpe!check_init_service!-a '".$sname."'",
								"_xiwizard" => $wizard_name,
								);		
							}
						break;
					
					case "processstate":
						
						$enabledprocs=$svcstate;
						foreach($enabledprocs as $pid => $pstate){
						
							$pname=$serviceargs["processstate"][$pid]["process"];
							$pdesc=$serviceargs["processstate"][$pid]["name"];
						
							$objs[]=array(
								"type" => OBJECTTYPE_SERVICE,
								"host_name" => $hostname,
								"service_description" => $pdesc,
								"use" => "xiwizard_nrpe_service",
								"check_command" => "check_nrpe!check_services!-a '".$pname."'",
								"_xiwizard" => $wizard_name,
								);		
							}
						break;
					
					default:
						break;
					}
				}
				
			//echo "OBJECTS:<BR>";
			//print_r($objs);
			//exit();
					
			// return the object definitions to the wizard
			$outargs[CONFIGWIZARD_NAGIOS_OBJECTS]=$objs;
		
			break;
			
		default:
			break;			
		}
		
	return $output;
	}
	
	
function linux_server_configwizard_get_distro_icon($linuxdistro){

	$icon="linux-server.png";
	
	switch($linuxdistro){
		case "RHEL":
			$icon="redhat.png";
			break;
		case "Fedora":
			$icon="fedora.png";
			break;
		case "CentOS":
			$icon="centos.png";
			break;
		case "Ubuntu":
			$icon="ubuntu.png";
			break;
		case "Debian":
			$icon="debian.png";
			break;
		default:
			break;
		}
		
	return $icon;
	}




?>
